import { PointTypes, PointTypesTypeof, PointXYZ } from './point-types';
import { Emscripten } from '../../types';
import Manager from './Manager';
export declare class Vector<T> {
    _native: Emscripten.NativeAPI;
    manager: Manager;
    constructor(_native: Emscripten.NativeAPI);
    get size(): number;
    set(index: number, value: T): boolean;
    get(index: number): T;
    push(value: T): void;
    isEmpty(): boolean;
    resize(count: number, value?: T): void;
    clear(): void;
}
declare class Indices extends Vector<number> {
    constructor(native?: Emscripten.NativeAPI);
}
declare class PCLHeader {
    _native: Emscripten.NativeAPI;
    manager: Manager;
    constructor(_native: Emscripten.NativeAPI);
    get seq(): number;
    get stamp(): bigint;
    get frameId(): string;
}
declare class PointIndices {
    _native: Emscripten.NativeAPI;
    manager: Manager;
    header: PCLHeader;
    indices: Indices;
    constructor(native?: Emscripten.NativeAPI);
}
declare class Points<T extends PointTypes> extends Vector<T> {
    private readonly _PT;
    constructor(_native: Emscripten.NativeAPI);
    get(index: number): T;
}
declare class PointCloud<T extends PointTypes = PointXYZ> {
    readonly _PT: PointTypesTypeof;
    _native: Emscripten.NativeAPI;
    manager: Manager;
    private _points?;
    constructor(_PT?: PointTypesTypeof, _native?: Emscripten.NativeAPI);
    get isOrganized(): boolean;
    get isDense(): boolean;
    set width(v: number);
    get width(): number;
    set height(v: number);
    get height(): number;
    get header(): PCLHeader;
    get size(): number;
    get points(): Points<T>;
    /**
     * Removes all points in a cloud and sets the width and height to 0.
     */
    clear(): void;
    /**
     * Resizes the container to contain `count` elements
     * @params count - New size of the point cloud
     * @params pt - The value to initialize the new points with
     */
    resize(count: number, pt?: T): void;
    /**
     * Insert a new point in the cloud, at the end of the container.
     * @description This breaks the organized structure of the cloud by setting the height to 1!
     * @params pt - The point to insert
     */
    addPoint(pt?: T | null): void;
}
declare function wrapPointCloud<T extends PointTypes>(_native: Emscripten.NativeAPI): PointCloud<T>;
declare function wrapPoints<T extends PointTypes>(_native: Emscripten.NativeAPI): Points<T>;
export { PointCloud, Points, wrapPointCloud, wrapPoints, PointIndices, PCLHeader, Indices };
