import { XYZPointTypes, PointXYZ } from '../../modules/common/point-types';
import { PointCloud, PointIndices } from '../../modules/common/PointCloud';
import ModelCoefficients from '../../modules/common/ModelCoefficients';
import { UnionToIntersection } from '../../types';
import PCLBase from '../../modules/common/PCLBase';
import { SacMethodTypes, SacModelTypes } from '../../modules/sample-consensus/constants';
import Search from '../../modules/search/Search';
declare class SACSegmentation<T extends XYZPointTypes = PointXYZ & Partial<UnionToIntersection<XYZPointTypes>>> extends PCLBase<T> {
    private _modelType;
    private _methodType;
    private _optimizeCoefficients;
    private _epsAngle;
    private _threshold;
    private _maxIterations;
    private _probability;
    private _samplesRadius;
    private _samplesRadiusSearch?;
    private _minRadius;
    private _maxRadius;
    constructor(random?: boolean);
    setModelType(model: SacModelTypes): void;
    getModelType(): SacModelTypes;
    setMethodType(method: SacMethodTypes): void;
    getMethodType(): SacMethodTypes;
    setDistanceThreshold(threshold: number): void;
    getDistanceThreshold(): number;
    setMaxIterations(maxIterations: number): void;
    getMaxIterations(): number;
    setProbability(probability: number): void;
    getProbability(): number;
    setRadiusLimits(minRadius: number, maxRadius: number): void;
    getRadiusLimits(): {
        minRadius: number;
        maxRadius: number;
    };
    setSamplesMaxDist(radius: number, search: Search<T>): void;
    getSamplesMaxDist(): {
        radius: number;
        search: Search<T> | undefined;
    };
    setEpsAngle(epsAngle: number): void;
    getEpsAngle(): number;
    setOptimizeCoefficients(optimizeCoefficients: boolean): void;
    getOptimizeCoefficients(): boolean;
    segment(inliers: PointIndices, modelCoefficients: ModelCoefficients): void;
    /**
     * Only supports `PointXYZ` type,
     * if it is not `PointXYZ` type, it will use `toXYZPointCloud` method to convert to `PointXYZ`
     */
    setInputCloud(cloud: PointCloud<T>): void;
}
export default SACSegmentation;
