import { Scene, ColorRepresentation, Vector3 } from 'three';
import { PointCloud } from '../modules/common/PointCloud';
interface CloudProperties {
    sizeAttenuation: boolean;
    size: number;
    color: ColorRepresentation;
    id: string;
}
declare class PointCloudViewer {
    scene: Scene;
    private camera;
    private renderer;
    private axesHelper?;
    private gridHelper?;
    private controls;
    private clouds;
    private cloudProperties;
    constructor(canvas: HTMLCanvasElement, width?: number, height?: number);
    addPointCloud(cloud: PointCloud, id?: string): void;
    addPointCloudByUrl(url: string, id?: string, onProgress?: ((event: ProgressEvent<EventTarget>) => void) | undefined): Promise<void>;
    addPointCloudByData(data: ArrayBuffer, id?: string): Promise<void>;
    removePointCloud(id?: string): void;
    setPointCloudProperties(properties?: Partial<CloudProperties>, id?: string): void;
    setBackgroundColor(bgc: ColorRepresentation): void;
    setCameraParameters(properties: {
        fov: number;
        aspect: number;
        near: number;
        far: number;
        position?: Pick<Vector3, 'x' | 'y' | 'z'>;
    }): void;
    setOrbitControls(properties: {
        enableRotate?: boolean;
        enableZoom?: boolean;
        enablePan?: boolean;
        enableDamping?: boolean;
        enabled?: boolean;
        minDistance?: number;
        maxDistance?: number;
        target?: Pick<Vector3, 'x' | 'y' | 'z'>;
    }): void;
    setAxesHelper(properties: {
        visible: boolean;
        size?: number;
    }): void;
    setGridHelper(properties: {
        visible: boolean;
        size?: number;
        divisions?: number;
    }): void;
    setSize(width: number, height: number): void;
    show(): void;
    hidden(): void;
    destroy(): void;
    private render;
    private createOrbitControls;
    private addPointCloudToScene;
}
export default PointCloudViewer;
